@@ -57,6 +57,7 @@ void get_source_info_list_callback(pa_context *context, const pa_source_info *in
 
 const QStringList *get_source_names(){
     if(source_names == NULL){
+        context_create();
         source_names = new QStringList();
         finished = false;
 
@@ -68,6 +69,7 @@ const QStringList *get_source_names(){
             qDebug("Received signal...");
         }while(! finished);
         pa_threaded_mainloop_unlock(threaded_main_loop);
+        context_stop();
     }
     return source_names;
 }
@@ -83,3 +85,10 @@ bool pa_available(){
     }
     return is_available;
 }
+
+void pa_shutdown(){
+    if(source_names != NULL){
+        delete source_names;
+    }
+    context_stop();
+}
