@@ -23,6 +23,9 @@
 
 PulseAudioRecordBackend::PulseAudioRecordBackend(QString source)
 {
+    qDebug("Using PulseAudio for recording...");
+    context_create();
+
     this->source = new QString(source);
     qDebug("Recording from: %s", this->source->toLocal8Bit().constData());
     connect_to_vu_meter_stream(this->source->toLocal8Bit().constData(), this);
