@@ -54,9 +54,6 @@ RecordDialog::RecordDialog(QWidget *parent) :
 
 #if defined(Q_WS_X11) && !defined(Q_WS_MAEMO_5)
     if(pa_available()){
-        qDebug("Using PulseAudio for recording...");
-        context_create();
-
         sources = (QStringList *) get_source_names();
 
         ui->sourceComboBox->addItems(*sources);
@@ -156,7 +153,6 @@ void RecordDialog::sourceChanged(int index){
         backend = NULL;
     }
 
-    context_create();
 #ifdef Q_WS_MAEMO_5
     switch(index){
     case 0:
