@@ -21,6 +21,7 @@
 #define RECORDDIALOG_H
 
 #include <QDialog>
+#include <QStringList>
 
 #include "src/io/audio/abstractaudiorecorderbackend.h"
 
@@ -41,6 +42,7 @@ private slots:
     void fileSelected(QString fileName);
     void recordPushed();
     void setVuMeter(float volume);
+    void sourceChanged(int index);
 
 private:
     Ui::RecordDialog *ui;
@@ -48,6 +50,7 @@ private:
     AbstractAudioRecorderBackend *backend;
 
     bool recording;
+    QStringList *sources;
 };
 
 #endif // RECORDDIALOG_H
